@@ -1,11 +1,30 @@
 import sys
 import base64
 
-__all__ = ['PY2', 'string_types', 'integer_types', 'text_type', 'bytes_types',
-           'bytes', 'long', 'input', 'decodebytes', 'encodebytes',
-           'bytestring', 'byte_ord', 'byte_chr', 'byte_mask', 'b', 'u', 'b2s',
-           'StringIO', 'BytesIO', 'is_callable', 'MAXSIZE',
-           'next', 'builtins']
+__all__ = [
+    "BytesIO",
+    "MAXSIZE",
+    "PY2",
+    "StringIO",
+    "b",
+    "b2s",
+    "builtins",
+    "byte_chr",
+    "byte_mask",
+    "byte_ord",
+    "bytes",
+    "bytes_types",
+    "decodebytes",
+    "encodebytes",
+    "input",
+    "integer_types",
+    "is_callable",
+    "long",
+    "next",
+    "string_types",
+    "text_type",
+    "u",
+]
 
 PY2 = sys.version_info[0] < 3
 
@@ -22,22 +41,13 @@ if PY2:
 
     import __builtin__ as builtins
 
-
-    def bytestring(s):  # NOQA
-        if isinstance(s, unicode):  # NOQA
-            return s.encode('utf-8')
-        return s
-
-
     byte_ord = ord  # NOQA
     byte_chr = chr  # NOQA
 
-
     def byte_mask(c, mask):
         return chr(ord(c) & mask)
 
-
-    def b(s, encoding='utf8'):  # NOQA
+    def b(s, encoding="utf8"):  # NOQA
         """cast unicode or bytes to bytes"""
         if isinstance(s, str):
             return s
@@ -46,10 +56,9 @@ if PY2:
         elif isinstance(s, buffer):  # NOQA
             return s
         else:
-            raise TypeError("Expected unicode or bytes, got %r" % s)
+            raise TypeError("Expected unicode or bytes, got {!r}".format(s))
 
-
-    def u(s, encoding='utf8'):  # NOQA
+    def u(s, encoding="utf8"):  # NOQA
         """cast bytes or unicode to unicode"""
         if isinstance(s, str):
             return s.decode(encoding)
@@ -58,26 +67,22 @@ if PY2:
         elif isinstance(s, buffer):  # NOQA
             return s.decode(encoding)
         else:
-            raise TypeError("Expected unicode or bytes, got %r" % s)
-
+            raise TypeError("Expected unicode or bytes, got {!r}".format(s))
 
     def b2s(s):
         return s
 
-
     import cStringIO
+
     StringIO = cStringIO.StringIO
     BytesIO = StringIO
 
-
     def is_callable(c):  # NOQA
         return callable(c)
 
-
     def get_next(c):  # NOQA
         return c.next
 
-
     def next(c):
         return c.next()
 
@@ -86,34 +91,33 @@ if PY2:
         def __len__(self):
             return 1 << 31
 
-
     try:
         len(X())
     except OverflowError:
         # 32-bit
-        MAXSIZE = int((1 << 31) - 1)        # NOQA
+        MAXSIZE = int((1 << 31) - 1)  # NOQA
     else:
         # 64-bit
-        MAXSIZE = int((1 << 63) - 1)        # NOQA
+        MAXSIZE = int((1 << 63) - 1)  # NOQA
     del X
 else:
     import collections
     import struct
     import builtins
+
     string_types = str
     text_type = str
     bytes = bytes
     bytes_types = bytes
     integer_types = int
+
     class long(int):
         pass
+
     input = input
     decodebytes = base64.decodebytes
     encodebytes = base64.encodebytes
 
-    def bytestring(s):
-        return s
-
     def byte_ord(c):
         # In case we're handed a string instead of an int.
         if not isinstance(c, int):
@@ -122,36 +126,37 @@ else:
 
     def byte_chr(c):
         assert isinstance(c, int)
-        return struct.pack('B', c)
+        return struct.pack("B", c)
 
     def byte_mask(c, mask):
         assert isinstance(c, int)
-        return struct.pack('B', c & mask)
+        return struct.pack("B", c & mask)
 
-    def b(s, encoding='utf8'):
+    def b(s, encoding="utf8"):
         """cast unicode or bytes to bytes"""
         if isinstance(s, bytes):
             return s
         elif isinstance(s, str):
             return s.encode(encoding)
         else:
-            raise TypeError("Expected unicode or bytes, got %r" % s)
+            raise TypeError("Expected unicode or bytes, got {!r}".format(s))
 
-    def u(s, encoding='utf8'):
+    def u(s, encoding="utf8"):
         """cast bytes or unicode to unicode"""
         if isinstance(s, bytes):
             return s.decode(encoding)
         elif isinstance(s, str):
             return s
         else:
-            raise TypeError("Expected unicode or bytes, got %r" % s)
+            raise TypeError("Expected unicode or bytes, got {!r}".format(s))
 
     def b2s(s):
         return s.decode() if isinstance(s, bytes) else s
 
     import io
-    StringIO = io.StringIO      # NOQA
-    BytesIO = io.BytesIO        # NOQA
+
+    StringIO = io.StringIO  # NOQA
+    BytesIO = io.BytesIO  # NOQA
 
     def is_callable(c):
         return isinstance(c, collections.Callable)
@@ -161,4 +166,4 @@ else:
 
     next = next
 
-    MAXSIZE = sys.maxsize       # NOQA
+    MAXSIZE = sys.maxsize  # NOQA
